#ifndef lint
static char sccs_id[] = "%W%	(TriChlor) %G% %U%";
#endif  /* lint */

#ifdef _WINDOWS
#pragma message("This program is not written for Windows.  Please compile as MSDOS.")
#endif
#ifdef _MSDOS
#include <stdlib.h>
#include <io.h>
#include <string.h>
#endif
#include <stdio.h>
#include <portable.h>
#include <vnkeys.h>

#define	streq(s1, s2)	(!strcmp(s1, s2))
#define	strneq(s1, s2)	(strcmp(s1, s2))

u_char	obuf[4096], ibuf[1024]; /* in/out buffers */


Usage()
{
    fprintf(stderr, "Usage: vn7to8 [-com <c>] [-v|-m|-l] [7-bit input file(s)]\n");
    fprintf(stderr, "              -com: <c> specifies the composition character, default is \"\\\"\n");
    fprintf(stderr, "              -v: sets the initial state to Vietnamese\n");
    fprintf(stderr, "              -m: sets the initial state to English\n");
    fprintf(stderr, "              -l: sets the initial state to Literal\n");
    fprintf(stderr, "\n");
    fprintf(stderr, "Purpose: Converts from 7-bit VIQR to 8-bit VISCII\n");
    fprintf(stderr, "Version: VISCII & VIQR 1.1\n");
    fprintf(stderr, "Author:  Cuong T. Nguyen (cuong@haydn.Stanford.EDU\n");
    fprintf(stderr, "         TriChlor Software Group---Copyrighted Freeware\n");
    exit(1);
}


main(ac, av)
    int	ac;
    char *av[];
{
    Vk_Fsm	id;
    Vk_State	state = VK_ST_VIETNAMESE;
    u_char	esc = VK_DEFAULT_ESC;
    u_char	bs = VK_DEFAULT_BS;
    int		i, n, arg;
    u_char FAR	*ic;
    u_char FAR	*oc;
    u_char	output[10];
    int		count;
    int		infd = -1; /* some non-zero to indicate not STDIN */

    vk_parse_args((int FAR *)&ac, (char FAR **)av, (u_char FAR *)&esc, (u_char FAR *)&bs);

    for (arg = 1; arg < ac; arg++) {
#ifdef _MSDOS
	if (*av[arg] == '-' || *av[arg] == '/') {
#else
	if (*av[arg] == '-') {
#endif
	    switch(av[arg][1]) {
	    case 'm':
            case 'M':
		state = VK_ST_ENGLISH;
		break;
	    case 'v':
            case 'V':
		state = VK_ST_VIETNAMESE;
		break;
	    case 'l':
            case 'L':
		state = VK_ST_LITERAL;
		break;
	    default:
		fprintf(stderr, "%s: unknown option \"%s\"\n", av[0], av[arg]);
		Usage();
	    }
	} else break; /* no more "-arguments" */
    }

    id = vk_init(state, esc, bs);
    vk_set(id, 1, VK_SET_BATCH); /* turn on batch mode */

    if (arg == ac) infd = 0;

while (1) {
    if (infd) { /* not getting input from STDIN */
	if (arg == ac) break; /* done */
	infd = open(av[arg], 0);
	if (infd < 0) {
	    fprintf(stderr, "%s: can't open file \"%s\"\n", av[0], av[arg]);
	    exit(1);    
	}
	arg++;
    }

    while ( (n = read(infd, ibuf, sizeof(ibuf))) > 0) {
	ic = ibuf;
	oc = obuf;
	for (i = 0; i < n; i++) {
	    vk_step(id, *ic++, oc, (int FAR *)&count);
	    if (count) oc += count;
	}
	write(1, obuf, oc-obuf);
    }

    if (infd == 0) break;
    close(infd);
}

    /* shut the machine down and flush any pending characters */
    vk_flush(id, (u_char FAR *)output, (int FAR *)&count);
    if (count) write(1, output, count);
    exit(0);

}
