#ifndef lint
static char sccs_id[] = "%W%	(TriChlor) %G% %U%";
#endif  /* lint */

#include <stdio.h>
#include <portable.h>
#include <vnkeys.h>

u_char	obuf[4096], ibuf[1024]; /* in/out buffers */


Usage()
{
    fprintf(stderr, "Usage: vn8to7 [-com <c>] [-m|-v] [8-bit input file(s)]\n");
    fprintf(stderr, "              -com: <c> specifies the composition character, default is \"\\\"\n");
    fprintf(stderr, "              -m: specifies English mode output\n");
    fprintf(stderr, "              -v: specifies Vietnamese mode output (default)\n");
    fprintf(stderr, "\n");
    fprintf(stderr, "Purpose: Converts from 8-bit VISCII to 7-bit VIQR\n");
    fprintf(stderr, "Version: VISCII & VIQR 1.1\n");
    fprintf(stderr, "Author:  Cuong T. Nguyen (cuong@haydn.Stanford.EDU\n");
    fprintf(stderr, "         TriChlor Software Group---Copyrighted Freeware\n");
    exit(1);
}


main(ac, av)
    int		ac;
    char	*av[];
{
    int		dummy;
    u_char	esc = VK_DEFAULT_ESC;
    Vk_State	state = VK_ST_VIETNAMESE;
    int		infd = -1; /* some non-zero to indicate not STDIN */
    int		n, arg;

    vk_parse_args(&ac, av, &esc, (u_char *) &dummy);

#define streq(s1, s2)	(!strcmp(s1, s2))
#define strneq(s1, s2)	(strcmp(s1, s2))

    for (arg = 1; arg < ac; arg++) {
#ifdef _MSDOS
	if (*av[arg] == '-' || *av[arg] == '/') {
#else
	if (*av[arg] == '-') {
#endif
	    switch(av[arg][1]) {
	    case 'm':
            case 'M':
		state = VK_ST_ENGLISH;
		break;
	    case 'v':
            case 'V':
		state = VK_ST_VIETNAMESE;
		break;
	    case 'l':
            case 'L':
		fprintf(stderr, "%s: conversion to LITERAL not suported.\n", av[0]);
		Usage();
	    default:
		fprintf(stderr, "%s: unknown option \"%s\"\n", av[0], av[arg]);
            	Usage();
	    }
	} else break; /* no more "-arguments" */
    }

    switch(state) {
    case VK_ST_VIETNAMESE:
	printf("%cV", esc);
	break;
    case VK_ST_ENGLISH:
	printf("%cM", esc);
	break;
    default:
	break;
    }
    fflush(stdout);

    if (arg == ac) infd = 0; /* use stdin only */

    while (1) {
	if (infd) { /* not getting input from STDIN */
	    if (arg == ac) break; /* done */
	    infd = open(av[arg], 0);
	    if (infd < 0) {
		fprintf(stderr, "%s: can't open file \"%s\"\n", av[0], av[arg]);
		exit(1);    
	    }
	    arg++;
	}

	while ( (n = read(infd, ibuf, sizeof(ibuf)-1)) > 0) {
	    ibuf[n] = '\0';
	    n = vk_8toqr(ibuf, obuf, esc, state);
	    write(1, obuf, n);
	}

	if (infd == 0) break; /* done reading STDIN, quit */
	close(infd); /* else close and open the next file */
    }

    exit(0);
}
